==> liquidwar6-0.0.3beta.tar.gz: liquidwar6-0.0.3beta/script/log.scm <==
;Liquid War 6 is a unique multiplayer wargame.
;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
;
;This program is free software; you can redistribute it and/or modify
;it under the terms of the GNU General Public License as published by
;the Free Software Foundation, either version 3 of the License, or
;(at your option) any later version.
;
;This program is distributed in the hope that it will be useful,
;but WITHOUT ANY WARRANTY; without even the implied warranty of
;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;GNU General Public License for more details.
;
;You should have received a copy of the GNU General Public License
;along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;
;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
;Contact author        : ufoot@ufoot.org

(define lw6-object->string-if-needed
  (lambda (object)
    (if (string? object)
	object
	(object->string object)
	)))

(define lw6-log-debug
  (lambda (msg)
    (
     c-lw6sys-log -1 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-info
  (lambda (msg)
    (
     c-lw6sys-log 0 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-notice
  (lambda (msg)
    (
     c-lw6sys-log 1 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-warning
  (lambda (msg)
    (
     c-lw6sys-log 2 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-error
  (lambda (msg)
    (
     c-lw6sys-log 3 (lw6-object->string-if-needed msg)
     )))

==> liquidwar6-0.0.10beta.tar.gz: liquidwar6-0.0.10beta/script/log.scm <==
;Liquid War 6 is a unique multiplayer wargame.
;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
;
;This program is free software; you can redistribute it and/or modify
;it under the terms of the GNU General Public License as published by
;the Free Software Foundation, either version 3 of the License, or
;(at your option) any later version.
;
;This program is distributed in the hope that it will be useful,
;but WITHOUT ANY WARRANTY; without even the implied warranty of
;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;GNU General Public License for more details.
;
;You should have received a copy of the GNU General Public License
;along with this program.  If not, see <http://www.gnu.org/licenses/>.
;
;
;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
;Contact author        : ufoot@ufoot.org

(define lw6-object->string-if-needed
  (lambda (object)
    (if (string? object)
	object
	(object->string object)
	)))

(define lw6-log-error
  (lambda (msg)
    (
     c-lw6sys-log 0 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-warning
  (lambda (msg)
    (
     c-lw6sys-log 1 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-notice
  (lambda (msg)
    (
     c-lw6sys-log 2 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-info
  (lambda (msg)
    (
     c-lw6sys-log 3 (lw6-object->string-if-needed msg)
     )))

(define lw6-log-debug
  (lambda (msg)
    (
     c-lw6sys-log 4 (lw6-object->string-if-needed msg)
     )))

(define tmp
  (lambda (msg)
    (
     c-lw6sys-log 5 (lw6-object->string-if-needed msg)
     )))
